@@ -80,5 +80,9 @@ class KDConcatDataset(ConcatDataset):
         # warning/exception here might make sense
         return self.datasets[0].all_wrapper_types
 
+    def worker_init_fn(self, rank, **kwargs):
+        for dataset in self.datasets:
+            dataset.worker_init_fn(rank, **kwargs)
+
     def __getitem__(self, idx):
         raise UseModeWrapperException
